summaryrefslogtreecommitdiff
path: root/src/KM_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/KM_util.h')
-rwxr-xr-xsrc/KM_util.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/KM_util.h b/src/KM_util.h
index 9ba6dc5..0f2af46 100755
--- a/src/KM_util.h
+++ b/src/KM_util.h
@@ -402,11 +402,12 @@ namespace Kumu
// decode and set value from string formatted by EncodeString
bool DecodeString(const char* datestr);
// Add the given number of days, hours, or minutes to the timestamp value.
// Values less than zero will cause the timestamp to decrease
void AddDays(i32_t);
void AddHours(i32_t);
void AddMinutes(i32_t);
+ void AddSeconds(i32_t);
// Read and write the timestamp value as a byte string having
// the following format:
@@ -402,11 +402,12 @@ namespace Kumu
// decode and set value from string formatted by EncodeString
bool DecodeString(const char* datestr);
- // Add the given number of days, hours, or minutes to the timestamp value.
+ // Add the given number of days, hours, minutes, or seconds to the timestamp value.
// Values less than zero will cause the timestamp to decrease
void AddDays(i32_t);